﻿/**
 * Real devices peer connection tests
 *
 * Currently has tests for:
 *   - createOffer
 *   - setLocalDescription
 *   - setRemoteDescription
 *   - addStream
 *   - getting of any attribute on the peer connection object
 *   - onaddstream
 *   - createAnswer
 *   - removeStream
 *   - close
 *   - onicecandidate
 *
 * Needs tests for:
 *   - addIceCandidate
 *   - updateIce
 *   - connectDataConnection
 *   - createDataChannel (add dc tests here too)
 *   - onopen
 *   - onstatechange
 *   - onremovestream
 *   - ongatheringchange
 *   - onicechange
 *   - onclosedconnection
 *   - onconnection
 *   - ondatachannel
 */

var firstPeerConnection = null;
var firstSDPOffer = null;
var firstSDPAnswer = null;
var firstIceCandidate = null;

var secondPeerConnection = null;
var secondSDPOffer = null;
var secondSDPAnswer = null;
var secondIceCandidate = null;

function turnOnLocalVideo(localVideo, constriants) {
	navigator.mozGetUserMedia(constriants, function(stream) {
		localVideo.mozSrcObject = stream;
		localVideo.play();
	}, function (err) {
		alert("Failed to start local video: " + err);
	});
}

function createPeerConnection1() {
	firstPeerConnection = new mozRTCPeerConnection();
}

function createPeerConnection2() {
	secondPeerConnection = new mozRTCPeerConnection();
}

function outputSDP(name, sessionDescription) {
	var output = name + ": ";
	
	if(sessionDescription) {
		output += sessionDescription.type + " " + sessionDescription.sdp;
	} else {
		output += "null\n";
	}

	console.log(output);
}

function outputSDPOffers() {
	outputSDP("firstSDPOffer", firstSDPOffer);
	outputSDP("secondSDPOffer", secondSDPOffer);
	outputSDP("firstSDPAnswer", firstSDPAnswer);
	outputSDP("secondSDPAnswer", secondSDPAnswer);
	alert("Success - See console log");
}

function outputPeerConnectionAttributes(connectionObj) {
	
	if(connectionObj) {
		var output = "";

		outputSDP("localDescription", connectionObj.localDescription);
		outputSDP("remoteDescription", connectionObj.remoteDescription);

		output += "See console for localDescription and remoteDescription output\n";
		output += "readyState: " + connectionObj.readyState + "\n";
		output += "iceGatheringState: " + connectionObj.iceGatheringState + "\n";
		output += "iceState: " + connectionObj.iceState + "\n";
		output += "localStreams length: " + connectionObj.localStreams.length + "\n";
		output += "remoteStreams length: " + connectionObj.remoteStreams.length + "\n";
		
		alert(output);
		
	} else {
		alert("Peer connection is null");
	}
	
}

function handleOnAddStreamForPeerConnection1() {
	if(firstPeerConnection) {
		firstPeerConnection.onaddstream = function(obj) {
			var pc1video1 = document.getElementById('pc1video');
			pc1video1.mozSrcObject = obj.stream;
			pc1video1.play();
		}
	} else {
		alert("Peer Connection needs to be created first");
	}
}

function handleOnAddStreamForPeerConnection2() {
	if(secondPeerConnection) {
		secondPeerConnection.onaddstream = function(obj) {
			var pc2video1 = document.getElementById('pc2video');
			pc2video1.mozSrcObject = obj.stream;
			pc2video1.play();
		}
	} else {
		alert("Peer Connection needs to be created first");
	}
}

function handleOnIceCandidateForPeerConnection1() {
	if(firstPeerConnection) {
		firstPeerConnection.onicecandidate = function(ice) {
			firstIceCandidate = ice;
			alert("Peer connection 1 onaddicecandidate fired with: " + ice);
		}
	} else {
		alert("Peer Connection needs to be created first");
	}
}

function handleOnIceCandidateForPeerConnection2() {
	if(secondPeerConnection) {
		secondPeerConnection.onicecandidate = function(ice) {
			secondIceCandidate = ice;
			alert("Peer connection 2 onaddicecandidate fired with: " + ice);
		}
	} else {
		alert("Peer Connection needs to be created first");
	}
}

function addStream(peerConnection, stream) {
	if(peerConnection) {
		peerConnection.addStream(stream);
	} else {
		alert("Peer Connection is null");
	}
}

function removeStream(peerConnection, stream) {
	if(peerConnection) {
		peerConnection.removeStream(stream);
	} else {
		alert("Peer Connection is null");
	}
}

function closePeerConnection(peerConnection) {
	if(peerConnection) {
		peerConnection.close();
	} else {
		alert("Peer Connection is null");
	}
}

function firstPeerConnectionOffer() {
	if(firstPeerConnection) {
		firstPeerConnection.createOffer(function(offer) {
			firstSDPOffer = offer;
		}, function(err) {
			alert("Create offer failed with: " + err);
		});
	} else {
		alert("First Peer Connection is null");
	}
}

function secondPeerConnectionOffer() {
	if(secondPeerConnection) {
		secondPeerConnection.createOffer(function(offer) {
			secondSDPOffer = offer;
		}, function(err) {
			alert("Create offer failed with: " + err);
		});
	} else {
		alert("Second Peer Connection is null");
	}
}

function setLocalDescription(peerConnection, offer) {
	if(peerConnection) {
		peerConnection.setLocalDescription(offer, function() {
			alert("Success: " + peerConnection.localDescription);
		}, function(err) {
			alert("Failure with: " + err);
		});
	} else {
		alert("Peer Connection is null");
	}
}

function setRemoteDescription(peerConnection, offer) {
	if(peerConnection) {
		peerConnection.setRemoteDescription(offer, function() {
			alert("Success: " + peerConnection.remoteDescription);
		}, function(err) {
			alert("Failure with: " + err);
		});
	} else {
		alert("Peer Connection is null");
	}
}

function firstPeerConnectionAnswer() {
	if(firstPeerConnection) {
		firstPeerConnection.createAnswer(function(answer) {
			firstSDPAnswer = answer;
		}, function(err) {
			alert("Create answer failed with: " + err);
		});
	} else {
		alert("First Peer Connection is null");
	}
}

function secondPeerConnectionAnswer() {
	if(secondPeerConnection) {
		secondPeerConnection.createAnswer(function(answer) {
			secondSDPAnswer = answer;
		}, function(err) {
			alert("Create answer failed with: " + err);
		});
	} else {
		alert("Second Peer Connection is null");
	}
}

window.addEventListener("DOMContentLoaded", function(err) {
	document.getElementById('localVideo1OnVideoOnly').onclick = function() {
		var localVideo1 = document.getElementById('localvideo1');
		turnOnLocalVideo(localVideo1, {video: true});
	};
	document.getElementById('localVideo1OnAudioOnly').onclick = function() {
		var localVideo1 = document.getElementById('localvideo1');
		turnOnLocalVideo(localVideo1, {audio: true});
	};
	document.getElementById('localVideo1OnVideoAudio').onclick = function() {
		var localVideo1 = document.getElementById('localvideo1');
		turnOnLocalVideo(localVideo1, {video: true, audio: true});
	};
	document.getElementById('localVideo2OnVideoOnly').onclick = function() {
		var localVideo2 = document.getElementById('localvideo2');
		turnOnLocalVideo(localVideo2, {video: true});
	};
	document.getElementById('localVideo2OnAudioOnly').onclick = function() {
		var localVideo2 = document.getElementById('localvideo2');
		turnOnLocalVideo(localVideo2, {audio: true});
	};
	document.getElementById('localVideo2OnVideoAudio').onclick = function() {
		var localVideo2 = document.getElementById('localvideo2');
		turnOnLocalVideo(localVideo2, {video: true, audio: true});
	};
	document.getElementById('createPC1').onclick = function() {
		createPeerConnection1();
	};
	document.getElementById('createPC2').onclick = function() {
		createPeerConnection2();
	};
	document.getElementById('closePC1').onclick = function() {
		closePeerConnection(firstPeerConnection);
	};
	document.getElementById('closePC2').onclick = function() {
		closePeerConnection(secondPeerConnection);
	};

	document.getElementById('onaddstreamPC1').onclick = handleOnAddStreamForPeerConnection1;
	document.getElementById('onaddstreamPC2').onclick = handleOnAddStreamForPeerConnection2;
	document.getElementById('onicecandidatePC1').onclick = handleOnIceCandidateForPeerConnection1;
	document.getElementById('onicecandidatePC2').onclick = handleOnIceCandidateForPeerConnection2;

	document.getElementById('getpc1attributes').onclick = function () {
		outputPeerConnectionAttributes(firstPeerConnection);
	};
	document.getElementById('getpc2attributes').onclick = function () {
		outputPeerConnectionAttributes(secondPeerConnection);
	};
	document.getElementById('addstreamuser1pc1').onclick = function () {
		var localVideo1 = document.getElementById('localvideo1');
		addStream(firstPeerConnection, localVideo1.mozSrcObject);
	};
	document.getElementById('addstreamuser2pc1').onclick = function () {
		var localVideo2 = document.getElementById('localvideo2');
		addStream(firstPeerConnection, localVideo2.mozSrcObject);
	};
	document.getElementById('addstreamuser1pc2').onclick = function () {
		var localVideo1 = document.getElementById('localvideo1');
		addStream(secondPeerConnection, localVideo1.mozSrcObject);
	};
	document.getElementById('addstreamuser2pc2').onclick = function () {
		var localVideo2 = document.getElementById('localvideo2');
		addStream(secondPeerConnection, localVideo2.mozSrcObject);
	};
	document.getElementById('removestreamuser1pc1').onclick = function () {
		var localVideo1 = document.getElementById('localvideo1');
		removeStream(firstPeerConnection, localVideo1.mozSrcObject);
	};
	document.getElementById('removestreamuser2pc1').onclick = function () {
		var localVideo2 = document.getElementById('localvideo2');
		removeStream(firstPeerConnection, localVideo2.mozSrcObject);
	};
	document.getElementById('removestreamuser1pc2').onclick = function () {
		var localVideo1 = document.getElementById('localvideo1');
		removeStream(secondPeerConnection, localVideo1.mozSrcObject);
	};
	document.getElementById('removestreamuser2pc2').onclick = function () {
		var localVideo2 = document.getElementById('localvideo2');
		removeStream(secondPeerConnection, localVideo2.mozSrcObject);
	};

	document.getElementById('outputsdpoffers').onclick = outputSDPOffers;
	document.getElementById('pc1offer').onclick = firstPeerConnectionOffer;
	document.getElementById('pc2offer').onclick = secondPeerConnectionOffer;

	document.getElementById('pc1setlocaldescription').onclick = function () {
		setLocalDescription(firstPeerConnection, firstSDPOffer);
	};
	document.getElementById('pc2setlocaldescription').onclick = function () {
		setLocalDescription(secondPeerConnection, secondSDPOffer);
	};
	document.getElementById('pc1setremotedescription').onclick = function () {
		setRemoteDescription(firstPeerConnection, firstSDPOffer);
	};
	document.getElementById('pc2setremotedescription').onclick = function () {
		setRemoteDescription(secondPeerConnection, secondSDPOffer);
	};

	document.getElementById('pc1answer').onclick = firstPeerConnectionAnswer;
	document.getElementById('pc2answer').onclick = secondPeerConnectionAnswer;
});
